==> jc-1.4.0.tar.gz: polyglot/main/Main.h <==
// public class polyglot.main.Main

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1b25b0e872a9cfe3 polyglot_main_Main

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_main_Main_H_
#define _JC_polyglot_main_Main_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Set$object;
struct _jc_polyglot_frontend_ExtensionInfo$object;

// Typedefs
typedef struct _jc_polyglot_main_Main$sub_refs	_jc_polyglot_main_Main$sub_refs;
typedef struct _jc_polyglot_main_Main$sub_nonrefs	_jc_polyglot_main_Main$sub_nonrefs;
typedef struct _jc_polyglot_main_Main$refs	_jc_polyglot_main_Main$refs;
typedef struct _jc_polyglot_main_Main$nonrefs	_jc_polyglot_main_Main$nonrefs;
typedef struct _jc_polyglot_main_Main$object	_jc_polyglot_main_Main$object;

typedef struct _jc_polyglot_main_Main$fields_struct	_jc_polyglot_main_Main$fields_struct;
typedef const struct _jc_polyglot_main_Main$vmethods	_jc_polyglot_main_Main$vmethods;
typedef const struct _jc_polyglot_main_Main$vtable	_jc_polyglot_main_Main$vtable;
typedef const struct _jc_polyglot_main_Main$vtype	_jc_polyglot_main_Main$vtype;

// Class fields structure
struct _jc_polyglot_main_Main$fields_struct {
	struct _jc_object	*timeTopics;
	struct _jc_java_lang_String$object	*verbose;
};
extern _jc_polyglot_main_Main$fields_struct _jc_polyglot_main_Main$class_fields;

// Constructors
extern void _jc_polyglot_main_Main$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_main_Main$object *);

// Virtual methods
extern struct _jc_object *_jc_polyglot_main_Main$method$explodeOptions$fedb0a122d4a637b(_jc_env *, struct _jc_polyglot_main_Main$object *, struct _jc_object_array *);
extern struct _jc_object *_jc_polyglot_main_Main$method$getExtensionInfo$40fa4bf0c1205899(_jc_env *, struct _jc_polyglot_main_Main$object *, struct _jc_object *);
extern void _jc_polyglot_main_Main$method$start$e582a3f00da406aa(_jc_env *, struct _jc_polyglot_main_Main$object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_main_Main$method_info$explodeOptions$fedb0a122d4a637b;
extern _jc_method _jc_polyglot_main_Main$method_info$getExtensionInfo$40fa4bf0c1205899;
extern _jc_method _jc_polyglot_main_Main$method_info$start$e582a3f00da406aa;

// Static methods
extern void _jc_polyglot_main_Main$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_object *_jc_polyglot_main_Main$method$loadExtension$df2174d1af8e0cc3(_jc_env *, struct _jc_java_lang_String$object *);
extern void _jc_polyglot_main_Main$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *);
extern void _jc_polyglot_main_Main$method$reportTime$49f94faed17cb503(_jc_env *, struct _jc_java_lang_String$object *, jint);

// Virtual methods structure
struct _jc_polyglot_main_Main$vmethods {
	struct _jc_object	*(*explodeOptions$fedb0a122d4a637b)(_jc_env *, struct _jc_polyglot_main_Main$object *, struct _jc_object_array *);
	struct _jc_object	*(*getExtensionInfo$40fa4bf0c1205899)(_jc_env *, struct _jc_polyglot_main_Main$object *, struct _jc_object *);
	void	(*start$e582a3f00da406aa)(_jc_env *, struct _jc_polyglot_main_Main$object *, struct _jc_object_array *);
};

// Vtable
struct _jc_polyglot_main_Main$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_main_Main$vmethods	polyglot_main_Main;
};

// Vtype
struct _jc_polyglot_main_Main$vtype {
	_jc_type			type;
	_jc_polyglot_main_Main$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_main_Main$sub_refs {
	struct _jc_object	*source;
};

// Reference instance fields (object)
struct _jc_polyglot_main_Main$refs {
    _jc_polyglot_main_Main$sub_refs	polyglot_main_Main;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_main_Main$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_main_Main$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_main_Main$sub_nonrefs	polyglot_main_Main;
};

// Object instance structure
struct _jc_polyglot_main_Main$object {
	_jc_polyglot_main_Main$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_main_Main$vtype	*vtype;
	_jc_polyglot_main_Main$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_main_Main$vtype _jc_polyglot_main_Main$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_main_Main, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_main_Main$class_object;

#endif	/* _JC_polyglot_main_Main_H_ */

==> jc-1.4.6.tar.gz: polyglot/main/Main.h <==
// public class polyglot.main.Main

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1b25b0e872a9cfe3 polyglot_main_Main

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_main_Main_H_
#define _JC_polyglot_main_Main_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Set$object;
struct _jc_polyglot_frontend_ExtensionInfo$object;

// Typedefs
typedef struct _jc_polyglot_main_Main$sub_refs	_jc_polyglot_main_Main$sub_refs;
typedef struct _jc_polyglot_main_Main$sub_nonrefs	_jc_polyglot_main_Main$sub_nonrefs;
typedef struct _jc_polyglot_main_Main$refs	_jc_polyglot_main_Main$refs;
typedef struct _jc_polyglot_main_Main$nonrefs	_jc_polyglot_main_Main$nonrefs;
typedef struct _jc_polyglot_main_Main$object	_jc_polyglot_main_Main$object;

typedef struct _jc_polyglot_main_Main$fields_struct	_jc_polyglot_main_Main$fields_struct;
typedef const struct _jc_polyglot_main_Main$vmethods	_jc_polyglot_main_Main$vmethods;
typedef const struct _jc_polyglot_main_Main$vtable	_jc_polyglot_main_Main$vtable;
typedef const struct _jc_polyglot_main_Main$vtype	_jc_polyglot_main_Main$vtype;

// Class fields structure
struct _jc_polyglot_main_Main$fields_struct {
	struct _jc_object	*timeTopics;
	struct _jc_java_lang_String$object	*verbose;
};
extern _jc_polyglot_main_Main$fields_struct _jc_polyglot_main_Main$class_fields;

// Constructors
extern void _jc_polyglot_main_Main$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_main_Main$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_polyglot_main_Main$method$explodeOptions$fedb0a122d4a637b(_jc_env *, struct _jc_polyglot_main_Main$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_main_Main$method$getExtensionInfo$40fa4bf0c1205899(_jc_env *, struct _jc_polyglot_main_Main$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_main_Main$method$start$e582a3f00da406aa(_jc_env *, struct _jc_polyglot_main_Main$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_main_Main$method_info$explodeOptions$fedb0a122d4a637b;
extern _jc_method _jc_polyglot_main_Main$method_info$getExtensionInfo$40fa4bf0c1205899;
extern _jc_method _jc_polyglot_main_Main$method_info$start$e582a3f00da406aa;

// Static methods
extern void _jc_polyglot_main_Main$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_main_Main$method$loadExtension$df2174d1af8e0cc3(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_main_Main$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern void _jc_polyglot_main_Main$method$reportTime$49f94faed17cb503(_jc_env *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_main_Main$vmethods {
	struct _jc_object	*(*explodeOptions$fedb0a122d4a637b)(_jc_env *, struct _jc_polyglot_main_Main$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getExtensionInfo$40fa4bf0c1205899)(_jc_env *, struct _jc_polyglot_main_Main$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*start$e582a3f00da406aa)(_jc_env *, struct _jc_polyglot_main_Main$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_main_Main$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_main_Main$vmethods	polyglot_main_Main;
};

// Vtype
struct _jc_polyglot_main_Main$vtype {
	_jc_type			type;
	_jc_polyglot_main_Main$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_main_Main$sub_refs {
	struct _jc_object	*source;
};

// Reference instance fields (object)
struct _jc_polyglot_main_Main$refs {
    _jc_polyglot_main_Main$sub_refs	polyglot_main_Main;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_main_Main$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_main_Main$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_main_Main$sub_nonrefs	polyglot_main_Main;
};

// Object instance structure
struct _jc_polyglot_main_Main$object {
	_jc_polyglot_main_Main$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_main_Main$vtype	*vtype;
	_jc_polyglot_main_Main$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_main_Main$vtype _jc_polyglot_main_Main$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_main_Main, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_main_Main$class_object;

#endif	/* _JC_polyglot_main_Main_H_ */
